@@ -6,14 +6,14 @@ from zope.component import getMultiAdapter
 
 # TODO: If you define any fields for the portlet configuration schema below
 # do not forget to uncomment the following import
-#from zope import schema
+from zope import schema
 from zope.formlib import form
 
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
 # TODO: If you require i18n translation for any of your schema fields below,
 # uncomment the following to import your package MessageFactory
-#from collective.portlet.userActionsPortlet import UserActionsPortletMessageFactory as _
+from collective.portlet.userActionsPortlet import UserActionsPortletMessageFactory as _
 
 
 class IUserActionsPortlet(IPortletDataProvider):
@@ -29,9 +29,10 @@ class IUserActionsPortlet(IPortletDataProvider):
     # empty interface - see also notes around the add form and edit form
     # below.
 
-    # some_field = schema.TextLine(title=_(u"Some field"),
-    #                              description=_(u"A field to use"),
-    #                              required=True)
+    header = schema.TextLine(title=_(u"Header"),
+                                  description=_(u"Header of the portlet, leave blank for none."),
+                                  required=False,
+                                  default=u"")
 
 
 class Assignment(base.Assignment):
@@ -43,16 +44,12 @@ class Assignment(base.Assignment):
 
     implements(IUserActionsPortlet)
 
-    # TODO: Set default values for the configurable parameters here
-
-    # some_field = u""
-
     # TODO: Add keyword parameters for configurable parameters here
-    # def __init__(self, some_field=u""):
-    #    self.some_field = some_field
+    def __init__(self, header=u""):
+        self.header = header
 
-    def __init__(self):
-        pass
+    #def __init__(self):
+    #    pass
 
     @property
     def title(self):
@@ -72,6 +69,9 @@ class Renderer(base.Renderer):
 
     render = ViewPageTemplateFile('useractionsportlet.pt')
     
+    def getHeader(self):
+        return self.data.header;
+    
     def user_actions(self):
         context_state = getMultiAdapter((self.context, self.request),
                                         name=u'plone_context_state')
@@ -80,37 +80,37 @@ class Renderer(base.Renderer):
         return actions
 
 
-#class AddForm(base.AddForm):
-#    """Portlet add form.
-#
-#    This is registered in configure.zcml. The form_fields variable tells
-#    zope.formlib which fields to display. The create() method actually
-#    constructs the assignment that is being added.
-#    """
-#    form_fields = form.Fields(IUserActionsPortlet)
-#
-#    def create(self, data):
-#        return Assignment(**data)
+class AddForm(base.AddForm):
+    """Portlet add form.
+
+    This is registered in configure.zcml. The form_fields variable tells
+    zope.formlib which fields to display. The create() method actually
+    constructs the assignment that is being added.
+    """
+    form_fields = form.Fields(IUserActionsPortlet)
+
+    def create(self, data):
+        return Assignment(header = data.get('header', u''))
 
 
 # NOTE: If this portlet does not have any configurable parameters, you
 # can use the next AddForm implementation instead of the previous.
 
-class AddForm(base.NullAddForm):
-     """Portlet add form.
-     """
-     def create(self):
-         return Assignment()
+#class AddForm(base.NullAddForm):
+#     """Portlet add form.
+#    """
+#     def create(self):
+#         return Assignment()
 
 
 # NOTE: If this portlet does not have any configurable parameters, you
 # can remove the EditForm class definition and delete the editview
 # attribute from the <plone:portlet /> registration in configure.zcml
 
-#class EditForm(base.EditForm):
-#    """Portlet edit form.
-#
-#    This is registered with configure.zcml. The form_fields variable tells
-#    zope.formlib which fields to display.
-#    """
-#    form_fields = form.Fields(IUserActionsPortlet)
+class EditForm(base.EditForm):
+    """Portlet edit form.
+
+    This is registered with configure.zcml. The form_fields variable tells
+    zope.formlib which fields to display.
+    """
+    form_fields = form.Fields(IUserActionsPortlet)
